@@ -41,6 +41,42 @@ class ModelsTestCase(DiscogsClientTestCase):
         self.assertTrue(isinstance(results[0], Artist))
         self.assertTrue(isinstance(results[1], Release))
 
+    def test_bytes_search(self):
+        results = self.d.search(b'trash80')
+        self.assertEqual(len(results), 13)
+        self.assertTrue(isinstance(results[0], Artist))
+        self.assertTrue(isinstance(results[1], Release))
+
+    def test_multiterm_search(self):
+        results = self.d.search('trash', '80')
+        self.assertEqual(len(results), 13)
+        self.assertTrue(isinstance(results[0], Artist))
+        self.assertTrue(isinstance(results[1], Release))
+
+    def test_multiterm_bytes_search(self):
+        results = self.d.search(b'trash', b'80')
+        self.assertEqual(len(results), 13)
+        self.assertTrue(isinstance(results[0], Artist))
+        self.assertTrue(isinstance(results[1], Release))
+
+    def test_multiterm_mixed_search(self):
+        results = self.d.search('trash', b'80')
+        self.assertEqual(len(results), 13)
+        self.assertTrue(isinstance(results[0], Artist))
+        self.assertTrue(isinstance(results[1], Release))
+
+    def test_kwargs_search(self):
+        results = self.d.search(artist='trash80')
+        self.assertEqual(len(results), 13)
+        self.assertTrue(isinstance(results[0], Artist))
+        self.assertTrue(isinstance(results[1], Release))
+
+    def test_kwargs_multiterm_search(self):
+        results = self.d.search(title='icarus', artist='trash80')
+        self.assertEqual(len(results), 13)
+        self.assertTrue(isinstance(results[0], Artist))
+        self.assertTrue(isinstance(results[1], Release))
+
     def test_utf8_search(self):
         uni_string = 'caf\xe9'
         try:
